# Arkouda Chapel Unit Tests

## Executing the Arkouda Chapel unit tests

All Chapel unit tests are executed via the following make goal:

```
make test
```

Note: the Python unit test is executed first in the make test goal, followed by
execution of the Chapel unit tests.
